From: Roland Häder <roland@mxchange.org>
Date: Tue, 16 Aug 2016 14:02:11 +0000 (+0200)
Subject: added business methods for fax and land-line numbers (retrival by id number)
X-Git-Url: https://git.mxchange.org/?a=commitdiff_plain;h=12f36cf1e165f827f235988a89fe138f09e485fa;p=jphone-lib.git

added business methods for fax and land-line numbers (retrival by id number)
---

diff --git a/src/org/mxchange/jphone/phonenumbers/phone/PhoneSessionBeanRemote.java b/src/org/mxchange/jphone/phonenumbers/phone/PhoneSessionBeanRemote.java
index da9a72c..177087a 100644
--- a/src/org/mxchange/jphone/phonenumbers/phone/PhoneSessionBeanRemote.java
+++ b/src/org/mxchange/jphone/phonenumbers/phone/PhoneSessionBeanRemote.java
@@ -33,15 +33,37 @@ import org.mxchange.jphone.phonenumbers.mobile.DialableMobileNumber;
 public interface PhoneSessionBeanRemote extends Serializable {
 
 	/**
 	 * Finds a cellphone entry by given id number
 	 * <p>
 	 * @param cellphoneId Cellphone entry id number
 	 * <p>
 	 * @return A valid cellphone instance
 	 * <p>
 	 * @throws PhoneEntityNotFoundException If the entity was not found
 	 */
-	DialableMobileNumber findMobileNumberById (Long cellphoneId) throws PhoneEntityNotFoundException;
+	DialableFaxNumber findFaxNumberById (final Long faxNumberId) throws PhoneEntityNotFoundException;
+
+	/**
+	 * Finds a land-line entry by given id number
+	 * <p>
+	 * @param landLineNumberId Land-line entry id number
+	 * <p>
+	 * @return A valid land-line instance
+	 * <p>
+	 * @throws PhoneEntityNotFoundException If the entity was not found
+	 */
+	DialableLandLineNumber findLandLineNumberById (final Long landLineNumberId) throws PhoneEntityNotFoundException;
+
+	/**
+	 * Finds a mobile entry by given id number
+	 * <p>
+	 * @param mobileNumberId Mobile entry id number
+	 * <p>
+	 * @return A valid mobile instance
+	 * <p>
+	 * @throws PhoneEntityNotFoundException If the entity was not found
+	 */
+	DialableMobileNumber findMobileNumberById (Long mobileNumberId) throws PhoneEntityNotFoundException;
 
 	/**
 	 * Returns a list of all cell phone numbers
@@ -33,15 +33,37 @@ import org.mxchange.jphone.phonenumbers.mobile.DialableMobileNumber;
 
 	/**
-	 * Finds a cellphone entry by given id number
+	 * Finds a fax entry by given id number
 	 * <p>
@@ -33,15 +33,37 @@ import org.mxchange.jphone.phonenumbers.mobile.DialableMobileNumber;
 	 * <p>
-	 * @param cellphoneId Cellphone entry id number
+	 * @param faxNumberId Fax entry id number
 	 * <p>
@@ -33,15 +33,37 @@ import org.mxchange.jphone.phonenumbers.mobile.DialableMobileNumber;
 	 * <p>
-	 * @return A valid cellphone instance
+	 * @return A valid fax instance
 	 * <p>
 	 * @throws PhoneEntityNotFoundException If the entity was not found